# Kubextract: ML Kubeflow Framework Generator
Kubextract is a framework generator for end-to-end machine learning development and automate kubeflow job deployment.

### How to use
- install pip3 or anaconda
- if you use pip3 ```pip3 install kubextract --upgrade``` or anaconda ```pip install kubextract --upgrade```
- run ```kubextract --location <your-path>```
- run ```kubextract --help``` for usage information

### Documentation
- see config documentation on ```docs/config```
- see architecture decision record on ```docs/adr```
- see example project on ```examples/```
